@@ -1,4 +1,5 @@
 #!/bin/sh
+NPROC_MIN=${NPROC_MIN-"1"}
 silent_run () {
   run_status=0
   command="$*"
@@ -18,10 +19,11 @@ run () {
 loop_mpirun () {
   mpi_status=0
   mpi_command="$*"
-  silent_run ${mpi_command}
-  if test $? -ne 0; then mpi_status=1; echo "        => *NO*"; fi
-  if test "${MPIRUN}" != "" -a "${NPROC_MAX}" != ""; then
-    nproc=1
+  if test "${MPIRUN}" = "" -o "${NPROC_MAX}" = ""; then
+    silent_run ${mpi_command}
+    if test $? -ne 0; then mpi_status=1; echo "        => *NO*"; fi
+  else
+    nproc=${NPROC_MIN}
     while test ${nproc} -le ${NPROC_MAX}; do
       silent_run "${MPIRUN} -np ${nproc} ${mpi_command}"
       if test $? -ne 0; then mpi_status=1; echo "        => *NO*"; fi
