@@ -22,7 +22,7 @@ orient2d (const basic_point<double>& a, const basic_point<double>& b,
 {
   init_orient();
   trace_macro ("orient2d");
-  return orient2d ((double*)a.x_, (double*)b.x_, (double*)c.x_);
+  return orient2d ((double*)a._x, (double*)b._x, (double*)c._x);
 }
 template<>
 double
@@ -31,6 +31,6 @@ orient3d (const basic_point<double>& a, const basic_point<double>& b,
 {
   init_orient();
   trace_macro ("orient3d");
-  return orient3d ((double*)a.x_, (double*)b.x_, (double*)c.x_, (double*)d.x_);
+  return orient3d ((double*)a._x, (double*)b._x, (double*)c._x, (double*)d._x);
 }
 } // namespace rheolef
