@@ -21,7 +21,7 @@
 
 #include "rheolef/config.h"
 
-#ifdef _RHEOLEF_USE_PARALLEL
+#ifdef _RHEOLEF_USE_DISTRIBUTED
 #include "geo_element_v2.cc"
 #else
 #include "geo_element_v1.cc"
