@@ -23,7 +23,7 @@
 
 #include "rheolef/config.h"
 
-#ifdef _RHEOLEF_USE_PARALLEL
+#ifdef _RHEOLEF_USE_DISTRIBUTED
 #include "rheolef/geo_element_v2.h"
 #else
 #include "rheolef/geo_element_v1.h"
