@@ -27,10 +27,11 @@
 //
 // date: 19 december 2010
 //
-#include "rheolef/parallel.h"
+#include "rheolef/distributed.h"
 #include "rheolef/reference_element.h"
 #include "rheolef/polymorphic_traits.h"
 
+#include <boost/serialization/serialization.hpp>
 #include <boost/array.hpp>
 #include <boost/mpl/vector.hpp>
 #include <boost/mpl/size.hpp>
@@ -69,32 +70,46 @@ public:
     static char tab_name [reference_element::max_size];
 
     virtual ~geo_element () {}
-    virtual enum_type type() const = 0;
+    geo_element& operator= (const geo_element& K) {
+        _dis_ie     = K._dis_ie;
+        _ios_dis_ie = K._ios_dis_ie;
+        return *this;
+    }
+    template<class Reference>
+    static void intrusive_set (Reference lhs, const geo_element& K);
+    virtual enum_type variant() const = 0;
+    enum_type type() const { return variant(); } // backward compatibility
     virtual char      name() const = 0;
     virtual size_type size() const = 0;
     virtual size_type dimension() const = 0;
-    operator reference_element () const { return reference_element(type()); }
+    operator reference_element () const { return reference_element(variant()); }
     virtual size_type  operator[] (size_type i) const = 0;
     virtual size_type& operator[] (size_type i)       = 0;
-    virtual size_type index() const { error_macro ("not yet"); return 0; } 
+    size_type dis_ie() const { return _dis_ie; }
+    size_type ios_dis_ie() const { return _ios_dis_ie; } 
+    void set_dis_ie    (size_type dis_ie1)     { _dis_ie = dis_ie1; } 
+    void set_ios_dis_ie(size_type ios_dis_ie1) { _ios_dis_ie = ios_dis_ie1; } 
+    size_type index() const { return dis_ie(); } // for backward compatibility
     virtual size_type edge (size_type i_edge) const { error_macro ("not yet"); return 0; } 
-    size_type par_old_ie() const { return _par_old_ie; } 
-    void set_par_old_ie(size_type par_old_ie1) { _par_old_ie = par_old_ie1; } 
 
     bool get_orientation_and_shift (const geo_element& S, 
 	  orientation_type& orient, size_type& shift) const;
 
     template <class Pool> struct get;
     template<class Archive>
-    void serialize (Archive& ar, const unsigned int version) { ar & _par_old_ie; }
+    void serialize (Archive& ar, const unsigned int version) {
+	ar & _dis_ie;
+	ar & _ios_dis_ie;
+    }
 // data:
 protected:
-    size_type _par_old_ie;
+    size_type _dis_ie;
+    size_type _ios_dis_ie;
 };
 //>verbatim:
 // =====================================================================
 class geo_element_p : public geo_element {
-    static const enum_type _type =  reference_element::p;
+    static const enum_type _variant =  reference_element::p;
     static const char      _name = 'p';
     static const size_type _size =  1;
     static const size_type _dim  =  0;
@@ -102,31 +117,33 @@ public:
     typedef boost::array<size_type,_size> array_type;
 
     geo_element_p () : geo_element() {
-	std::fill (_vertex.begin(), _vertex.end(), std::numeric_limits<size_type>::max());
+	geo_element::_dis_ie = std::numeric_limits<size_type>::max();
     }
     geo_element_p (size_type a) : geo_element() {
-	_vertex[0] = a;
+	geo_element::_dis_ie = a;
     } 
-    geo_element_p (const array_type& K) {  _vertex = K; }
     ~geo_element_p () {}
-    enum_type type() const      { return _type; };
+    geo_element_p& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_p& K1 = dynamic_cast<const geo_element_p&>(K);
+	geo_element::_dis_ie = K.geo_element::dis_ie();
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
-    size_type  operator[] (size_type i) const { return _vertex[i]; }
-    size_type& operator[] (size_type i)       { return _vertex[i]; }
+    size_type  operator[] (size_type) const { return geo_element::_dis_ie; }
+    size_type& operator[] (size_type)       { return geo_element::_dis_ie; }
     template<class Archive>
     void serialize (Archive& ar, const unsigned int version) {
         ar & boost::serialization::base_object<geo_element>(*this);
-	ar & _vertex;
     }
-// data:
-protected:
-    array_type _vertex;
 };
 // =====================================================================
 class geo_element_e : public geo_element {
-    static const enum_type _type =  reference_element::e;
+    static const enum_type _variant =  reference_element::e;
     static const char      _name = 'e';
     static const size_type _size =  2;
     static const size_type _dim  =  1;
@@ -142,7 +159,14 @@ public:
     } 
     geo_element_e (const array_type& K) {  _vertex = K; }
     ~geo_element_e () {}
-    enum_type type() const      { return _type; };
+    geo_element_e& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_e& K1 = dynamic_cast<const geo_element_e&>(K);
+        std::copy (K1._vertex.begin(), K1._vertex.end(), _vertex.begin());
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
@@ -159,7 +183,7 @@ protected:
 };
 // =====================================================================
 class geo_element_t : public geo_element {
-    static const enum_type _type =  reference_element::t;
+    static const enum_type _variant =  reference_element::t;
     static const char      _name = 't';
     static const size_type _size =  3;
     static const size_type _dim  =  2;
@@ -176,7 +200,14 @@ public:
     } 
     geo_element_t (const array_type& K) {  _vertex = K; }
     ~geo_element_t () {}
-    enum_type type() const      { return _type; };
+    geo_element_t& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_t& K1 = dynamic_cast<const geo_element_t&>(K);
+        std::copy (K1._vertex.begin(), K1._vertex.end(), _vertex.begin());
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
@@ -193,7 +224,7 @@ protected:
 };
 // =====================================================================
 class geo_element_q : public geo_element {
-    static const enum_type _type =  reference_element::q;
+    static const enum_type _variant =  reference_element::q;
     static const char      _name = 'q';
     static const size_type _size =  4;
     static const size_type _dim  =  2;
@@ -210,7 +241,14 @@ public:
     } 
     geo_element_q (const array_type& K) {  _vertex = K; }
     ~geo_element_q () {}
-    enum_type type() const      { return _type; };
+    geo_element_q& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_q& K1 = dynamic_cast<const geo_element_q&>(K);
+        std::copy (K1._vertex.begin(), K1._vertex.end(), _vertex.begin());
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
@@ -227,7 +265,7 @@ protected:
 };
 // =====================================================================
 class geo_element_T : public geo_element {
-    static const enum_type _type =  reference_element::T;
+    static const enum_type _variant =  reference_element::T;
     static const char      _name = 'T';
     static const size_type _size =  4;
     static const size_type _dim  =  3;
@@ -244,7 +282,14 @@ public:
     } 
     geo_element_T (const array_type& K) {  _vertex = K; }
     ~geo_element_T () {}
-    enum_type type() const      { return _type; };
+    geo_element_T& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_T& K1 = dynamic_cast<const geo_element_T&>(K);
+        std::copy (K1._vertex.begin(), K1._vertex.end(), _vertex.begin());
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
@@ -261,7 +306,7 @@ protected:
 };
 // =====================================================================
 class geo_element_P : public geo_element {
-    static const enum_type _type =  reference_element::P;
+    static const enum_type _variant =  reference_element::P;
     static const char      _name = 'P';
     static const size_type _size =  6;
     static const size_type _dim  =  3;
@@ -281,7 +326,14 @@ public:
     } 
     geo_element_P (const array_type& K) {  _vertex = K; }
     ~geo_element_P () {}
-    enum_type type() const      { return _type; };
+    geo_element_P& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_P& K1 = dynamic_cast<const geo_element_P&>(K);
+        std::copy (K1._vertex.begin(), K1._vertex.end(), _vertex.begin());
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
@@ -298,7 +350,7 @@ protected:
 };
 // =====================================================================
 class geo_element_H : public geo_element {
-    static const enum_type _type =  reference_element::H;
+    static const enum_type _variant =  reference_element::H;
     static const char      _name = 'H';
     static const size_type _size =  8;
     static const size_type _dim  =  3;
@@ -320,7 +372,14 @@ public:
     } 
     geo_element_H (const array_type& K) {  _vertex = K; }
     ~geo_element_H () {}
-    enum_type type() const      { return _type; };
+    geo_element_H& operator= (const geo_element& K) {
+        geo_element::operator= (K);
+	check_macro (K.variant() == variant(), "incompatible assignment from `"<<K.name()<<"' to `"<<name()<<"' geo_element");	
+	const geo_element_H& K1 = dynamic_cast<const geo_element_H&>(K);
+        std::copy (K1._vertex.begin(), K1._vertex.end(), _vertex.begin());
+        return *this;
+    }
+    enum_type variant() const   { return _variant; };
     char      name() const      { return _name; };
     size_type size() const      { return _size; }
     size_type dimension() const { return _dim; };
@@ -422,47 +481,30 @@ dump (const geo_element& K1, Array& K2) {
 	}
 } 
 // -------------------------------------------------------------------
+// helper for polymorphic_array and polymorphic_map
+// -------------------------------------------------------------------
+template<class Reference>
+inline
+void
+geo_element::intrusive_set (Reference lhs, const geo_element& K) 
+{
+  switch (K.name()) {
+    case 'p': lhs = dynamic_cast<const geo_element_p&>(K); break;
+    case 'e': lhs = dynamic_cast<const geo_element_e&>(K); break;
+    case 't': lhs = dynamic_cast<const geo_element_t&>(K); break;
+    case 'q': lhs = dynamic_cast<const geo_element_q&>(K); break;
+    case 'T': lhs = dynamic_cast<const geo_element_T&>(K); break;
+    case 'P': lhs = dynamic_cast<const geo_element_P&>(K); break;
+    case 'H': lhs = dynamic_cast<const geo_element_H&>(K); break;
+    default: error_macro ("unexpected geo_element type `" << K.name() << "'");
+  }
+}
+// -------------------------------------------------------------------
 // helper for long typedef list:
 // -------------------------------------------------------------------
 
 namespace mpl = boost::mpl;
 
-template <int Dimension>
-struct geo_element_dimension {
-    typedef mpl::vector0<> derived_type;
-    static const size_t n_derived = mpl::size<derived_type>::value;
-};
-template <>
-struct geo_element_dimension<0> {
-    typedef mpl::vector1<
-	geo_element_p>
-    derived_type;
-    static const size_t n_derived = mpl::size<derived_type>::value;
-};
-template <>
-struct geo_element_dimension<1> {
-    typedef mpl::vector1<
-	geo_element_e>
-    derived_type;
-    static const size_t n_derived = mpl::size<derived_type>::value;
-};
-template <>
-struct geo_element_dimension<2> {
-    typedef mpl::vector2<
-	geo_element_t,
-	geo_element_q>
-    derived_type;
-    static const size_t n_derived = mpl::size<derived_type>::value;
-};
-template <>
-struct geo_element_dimension<3> {
-    typedef mpl::vector3<
-	geo_element_T,
-	geo_element_P,
-	geo_element_H>
-    derived_type;
-    static const size_t n_derived = mpl::size<derived_type>::value;
-};
 // default polymorphic array derived type allows the 3d full family:
 template <>
 struct polymorphic_traits<geo_element> {
