@@ -313,10 +313,7 @@ EXAMPLES:
   This command generates the isosurface as a 3d surface mesh in
   @file{.geo} format. This is suitable for others treatments.
 
-AUTHOR: 
-    LMC-IMAG, 38041 Grenoble cedex 9, France
-    | Nicolas.Roquet@imag.fr
-    | Pierre.Saramito@imag.fr
+AUTHOR: Pierre.Saramito@imag.fr
 SEE ALSO:
     class "field(3)", "space"(3), class "geo"(3), class "base"(3)
 DATE:
