@@ -487,10 +487,7 @@ and the number of sides. Follows the sides
        	1 1 1
        	e   2 3
 @end example
-AUTHOR: 
-    LMC-IMAG, 38041 Grenoble cedex 9, France
-    | Nicolas.Roquet@imag.fr
-    | Pierre.Saramito@imag.fr
+AUTHOR: Pierre.Saramito@imag.fr
 SEE ALSO:
     "geo"(3), "rheostream"(3), "gnuplot"(1)
 DATE:
