@@ -40,14 +40,9 @@ EXAMPLE:
 @noindent
  A sample usage of the geo class writes
  @example
- #include "rheolef.h"
- using namespace rheolef;
- using namespace std;
- int main () @{
    geo omega;
    cin >> omega;
    cout << mayavi << full << omega;
- @}
  @end example
 
 DESCRIPTION:
@@ -132,11 +127,7 @@ ACCESS TO DOMAINS:
 ENVIRONS:
    RHEOPATH: search path for geo data file.
    Also @ref{form class}.
-AUTHORS:
-    LMC-IMAG, 38041 Grenoble cedex 9, France
-   | Nicolas.Roquet@imag.fr
-   | Pierre.Saramito@imag.fr
-   | Jocelyn.Etienne@imag.fr
+AUTHORS: Pierre.Saramito@imag.fr, Jocelyn.Etienne@imag.fr
 DATE:   12 may 1997  update:  26 mar 2002
 End:
 */
