@@ -155,10 +155,7 @@ The method @code{domain_index(global_dof)} gives the unknown or blocked
 numbering from the initial numbering, suppling a given @code{global_dof},
 related to the space @code{V}.
 
-AUTHORS:
-  | Pierre.Saramito@imag.fr
-  | Nicolas.Roquet@imag.fr
-  LMC-IMAG, 38041 Grenoble cedex 9, France
+AUTHORS: Pierre.Saramito@imag.fr
 DATE:   14 may 1997   update: 28 jan 1998
 METHODS: @space
 End:
