@@ -24,22 +24,25 @@ namespace rheolef {
 using namespace std;
 using namespace ublas;
 
-template<class T>
+template<class T, class M>
 void 
-mass<T>::operator() (const geo_element& K, ublas::matrix<T>& m) const
+mass<T,M>::operator() (const geo_element& K, ublas::matrix<T>& m) const
 {
   build_scalar_mass (K, m);
 }
-template<class T>
+template<class T, class M>
 void
-mass<T>::initialize ()
+mass<T,M>::initialize ()
 {
-    warning_macro ("call set_n_derivative...");
     this->set_n_derivative(0);
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-template class mass<Float>;
+template class mass<Float,sequential>;
+
+#ifdef _RHEOLEF_HAVE_MPI
+template class mass<Float,distributed>;
+#endif // _RHEOLEF_HAVE_MPI
 
 } // namespace rheolef
