@@ -64,10 +64,16 @@ End:
 */
 
 // for simplicity: include alls
+# include "rheolef/iorheo.h"
 # include "rheolef/skit.h"
 # include "rheolef/pcg.h"
 # include "rheolef/eye.h"
+# include "rheolef/geo.h"
+# include "rheolef/geo_domain_indirect.h"
+# include "rheolef/geo_domain.h"
 # include "rheolef/field.h"
+# include "rheolef/field_expr.h"
+# include "rheolef/field_expr_ops.h"
 # include "rheolef/form.h"
 # include "rheolef/interpolate.h"
 
