@@ -22,6 +22,7 @@
 /// =========================================================================
 
 #include "rheolef/geo.h"
+#include "rheolef/geo_domain.h"
 #include "rheolef/element.h"
 
 namespace rheolef {
@@ -30,7 +31,7 @@ namespace rheolef {
 // space_act = a domain + an act (block, unblock)
 // =====================================================================
 
-template <class T, class M>
+template <class M>
 class space_act {
 public:
 
@@ -44,29 +45,29 @@ public:
 // allocators:
 
     space_act() : _dom(), _act() {}
-    space_act(const domain_basic<T,M>& dom, act_type act)
+    space_act(const domain_indirect_basic<M>& dom, act_type act)
 	: _dom(dom), _act(act) {}
-    space_act(const space_act<T,M>& sp)
+    space_act(const space_act<M>& sp)
 	: _dom(sp._dom), _act(sp._act) {}
 
 // accessors:
 
-    const domain_basic<T,M>& get_domain() const { return _dom; }
-    act_type                 get_act()    const { return _act; }
+    const domain_indirect_basic<M>& get_domain_indirect() const { return _dom; }
+    act_type                    get_act()         const { return _act; }
     
 // data:
 protected:
-    domain_basic<T,M> _dom;
-    act_type          _act;
+    domain_indirect_basic<M> _dom;
+    act_type                 _act;
 };
 // =====================================================================
 // space_constitution = a table of acts
 // =====================================================================
 
 template <class T, class M>
-class space_constitution_rep : public std::vector<space_act<T,M> > {
+class space_constitution_rep : public std::vector<space_act<M> > {
 public:
-    typedef std::vector<space_act<T,M> >   base;
+    typedef std::vector<space_act<M> >     base;
     typedef typename  base::size_type      size_type;
     typedef typename  base::const_iterator const_iterator;
 
@@ -75,7 +76,7 @@ public:
     space_constitution_rep()
       : base(), _omega(), _element() {}
     space_constitution_rep(const geo_basic<T,M>& omega, std::string approx)
-      : base(), _omega(omega), _element(approx) {}
+      : base(), _omega(compact(omega)), _element(approx) {}
     space_constitution_rep (const space_constitution_rep<T,M>& scr)
       : base(scr), _omega(scr._omega), _element(scr._element)
     {
@@ -96,14 +97,17 @@ public:
     void set_geo (const geo_basic<T,M>& omega)  { _omega = omega; }
     void set_element (const element<T>& elt)    { _element = elt; }
 
-    void block  (const domain_basic<T,M>& dom) {
-    	warning_macro ("block domain "<<dom.name());
-	base::push_back (space_act<T,M> (dom, space_act<T,M>::block));
+    void block  (const domain_indirect_basic<M>& dom) {
+	base::push_back (space_act<M> (dom, space_act<M>::block));
     }
-    void unblock(const domain_basic<T,M>& dom) {
-	base::push_back (space_act<T,M> (dom, space_act<T,M>::unblock));
+    void unblock(const domain_indirect_basic<M>& dom) {
+	base::push_back (space_act<M> (dom, space_act<M>::unblock));
     }
 
+// comparator:
+
+    bool operator== (const space_constitution_rep<T,M>& V2) const { return _omega == V2._omega && _element == V2._element; }
+
 // data:
 protected:
     geo_basic<T,M>                   _omega;
@@ -135,16 +139,19 @@ public:
     const_iterator begin() const { return base::data().begin(); }
     const_iterator end()   const { return base::data().end(); }
 
+// comparator:
+
+    bool operator== (const space_constitution<T,M>& V2) const { return base::data().operator==(V2.data()); }
+
 // modifiers
 
     void set_geo (const geo_basic<T,M>& omega) { base::data().set_geo (omega); }
     void set_element (const element<T>& elt)   { base::data().set_element (elt); }
 
-    void block  (const domain_basic<T,M>& dom) {
-    	warning_macro ("block domain "<<dom.name());
+    void block  (const domain_indirect_basic<M>& dom) {
 	base::data().block(dom);
     }
-    void unblock(const domain_basic<T,M>& dom) { base::data().unblock(dom); }
+    void unblock(const domain_indirect_basic<M>& dom) { base::data().unblock(dom); }
 };
 // =====================================================================
 // a dof = a degree-of-freedom 
@@ -186,11 +193,14 @@ namespace boost {
 
 namespace rheolef {
 
+// forward declaration:
+template <class T, class M> class field_basic;
+
 // =====================================================================
-// 1) representation: space_rep, space_seq_rep and space_mpi_rep
+// 1) representation: space_base_rep and space_rep
 // =====================================================================
 template <class T, class M>
-class space_rep {
+class space_base_rep {
 public:
 
 // typedefs:
@@ -199,35 +209,48 @@ public:
 
 // allocators:
 
-    space_rep ();
-    space_rep (const geo_basic<T,M>& omega, std::string approx);
+    space_base_rep ();
+    space_base_rep (const geo_basic<T,M>& omega, std::string approx);
 
 // accessors:
 
-    void block  (const domain_basic<T,M>& dom) {
-    	warning_macro ("block domain "<<dom.name());
-	no_freeze_guard();
-	_constit.block  (dom);
-    }
-    void unblock(const domain_basic<T,M>& dom) {no_freeze_guard(); _constit.unblock(dom);}
-
     const distributor&  ownership() const { return _idof2blk_iub.ownership(); }
     size_type                size() const { return ownership().size(); }
-    size_type            par_size() const { return ownership().par_size(); }
+    size_type            dis_size() const { return ownership().dis_size(); }
     const communicator&      comm() const { return ownership().comm(); }
 
     const geo_basic<T,M>& get_geo() const { return _constit.get_geo(); }
     const element<T>& get_element() const { return _constit.get_element(); }
 
+    std::string get_stamp() const; /// e.g. "P1(square)", for field_expr<Expr> checks
+
+    void block  (const domain_indirect_basic<M>& dom) { no_freeze_guard(); _constit.block  (dom); }
+    void unblock(const domain_indirect_basic<M>& dom) {no_freeze_guard(); _constit.unblock(dom);}
+
     bool                 is_blocked (size_type     idof) const { freeze_guard(); return _idof2blk_iub [idof].is_blocked(); }
     size_type                   iub (size_type     idof) const { freeze_guard(); return _idof2blk_iub [idof].iub(); }
 
     const distributor& iu_ownership() const { freeze_guard(); return _iu_ownership; }
     const distributor& ib_ownership() const { freeze_guard(); return _ib_ownership; }
 
-    void set_par_dof (const geo_element& K, std::vector<size_type>& par_idof) const;
+    void get_dis_idof (const geo_element& K, std::vector<size_type>& dis_idof) const;
+
+    template <class Function>
+    T momentum (Function f, size_type idof) const;
+
+    array<size_type, M> build_indirect_array (
+    	const domain_indirect_basic<M>& indirect) const;
+
+// comparator:
+
+    bool operator== (const space_base_rep<T,M>& V2) const { 
+	return _constit.operator==(V2._constit); } // TODO: compare also blocked/unknown sizes:
+
+    friend bool are_compatible (const space_base_rep<T,M>& V1, const space_base_rep<T,M>& V2) {
+    	return V1._constit.operator==(V2._constit); }
 
 protected:
+    template <class T1, class M1> friend class field_basic;
 // internal:
     void freeze_guard() const {
     	if (_is_freezed) return;
@@ -247,59 +270,93 @@ protected:
     mutable distributor              _ib_ownership;  // blocked values distribution
 };
 // ---------------------------------------------------------------------
+// momentum/interpolation implementation
+// ---------------------------------------------------------------------
+template <class T, class M>
+template <class Function>
+/* TODO: typename function_traits<Function>::result_type */
+inline
+T
+space_base_rep<T,M>::momentum (
+    Function  f,
+    size_type idof) const
+{
+#ifdef TO_CLEAN
+    // P1 Lagrange only ; TODO: extend
+    const basic_point<T>& x = get_geo().vertex (idof);
+    return f(x);
+#endif // TO_CLEAN
+    basic_point<T> x = get_element().x_dof (idof, get_geo());
+    return f(x);
+}
+// ---------------------------------------------------------------------
+template <class T, class M> class space_rep {};
+
 template <class T>
-class space_seq_rep : public space_rep<T,sequential> {
+class space_rep<T,sequential> : public space_base_rep<T,sequential> {
 public:
 
 // typedefs:
 
-    typedef space_rep<T,sequential> base;
+    typedef space_base_rep<T,sequential> base;
     typedef typename base::size_type size_type;
 
 // allocators:
 
-    space_seq_rep (const geo_basic<T,sequential>& omega, std::string approx);
+    space_rep (const geo_basic<T,sequential>& omega = (geo_basic<T,sequential>()), std::string approx = "");
 
 // compatibility with the distributed interface:
 
-    bool             par_is_blocked (size_type par_idof) const { return is_blocked(par_idof); }
-    size_type               par_iub (size_type par_idof) const { return iub(par_idof); }
-    size_type     idof2par_old_idof (size_type     idof) const { return idof; }
+    bool             dis_is_blocked (size_type dis_idof) const { return is_blocked(dis_idof); }
+    size_type               dis_iub (size_type dis_idof) const { return iub(dis_idof); }
+
+    const distributor& ios_ownership() const { return base::ownership(); }
+    size_type     idof2ios_dis_idof (size_type     idof) const { return idof; }
+    size_type     ios_idof2dis_idof (size_type ios_idof) const { return ios_idof; }
 };
 // ---------------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
 template <class T>
-class space_mpi_rep : public space_rep<T,distributed> {
+class space_rep<T,distributed> : public space_base_rep<T,distributed> {
 public:
 
 // typedefs:
 
-    typedef space_rep<T,distributed> base;
+    typedef space_base_rep<T,distributed> base;
     typedef typename base::size_type size_type;
 
 // allocators:
 
-    space_mpi_rep (const geo_basic<T,distributed>& omega, std::string approx);
+    space_rep (const geo_basic<T,distributed>& omega = (geo_basic<T,distributed>()), std::string approx = "");
 
 // accessors:
 
     const communicator&      comm() const { return base::comm(); }
 
-    bool             par_is_blocked (size_type par_idof) const;
-    size_type               par_iub (size_type par_idof) const;
-    size_type     idof2par_old_idof (size_type     idof) const { base::freeze_guard(); return _idof2par_old_idof [idof]; }
+    bool             dis_is_blocked (size_type dis_idof) const;
+    size_type               dis_iub (size_type dis_idof) const;
+
+    const distributor& ios_ownership() const { return _ios_idof2dis_idof.ownership(); }
+    size_type     idof2ios_dis_idof (size_type     idof) const { base::freeze_guard(); return _idof2ios_dis_idof [idof]; }
+    size_type     ios_idof2dis_idof (size_type ios_idof) const { base::freeze_guard(); return _ios_idof2dis_idof [ios_idof]; }
+#ifdef TO_CLEAN
+    void get_ios_dis_idof (const geo_element& K, std::vector<size_type>& ios_dis_idof) const;
+#endif // TO_CLEAN
 
 protected:
+    template <class T1, class M1> friend class field_basic;
     typedef std::map <size_type, size_type, std::less<size_type>,
             heap_allocator<std::pair<size_type,size_type> > >           map_type;
     typedef std::map <size_type, space_pair_type, std::less<size_type>,
             heap_allocator<std::pair<size_type,space_pair_type> > >     map_pair_type;
-// internal:
+// internal procedures:
     void freeze_body() const;
+    void append_external_dof (const geo_basic<T,distributed>& dom, std::set<size_type>& ext_dof_set) const;
 // data:
-    array<size_type>               _idof2par_old_idof;   // permut to/from old dof numbering (before geo part), for i/o
+    array<size_type>               _idof2ios_dis_idof;   // permut to/from ios dof numbering (before geo part), for i/o
+    array<size_type>               _ios_idof2dis_idof;
 // mutable data, affected by freeze_*()const:
-    mutable map_pair_type          _ext_par_idof2blk_par_iub; // same for partition bdry dofs
+    mutable map_pair_type          _ext_dis_idof2blk_dis_iub; // same for partition bdry dofs
 };
 #endif // _RHEOLEF_HAVE_MPI
 // ====================================================================
@@ -327,45 +384,61 @@ typedef space_basic<Float> space;
 // ---------------------------------------------------------------------
 //<verbatim:
 template <class T>
-class space_basic<T,sequential> : public smart_pointer<space_seq_rep<T> > {
+class space_basic<T,sequential> : public smart_pointer<space_rep<T,sequential> > {
 public:
 
 // typedefs:
 
-    typedef space_seq_rep<T>        rep;
+    typedef space_rep<T,sequential> rep;
     typedef smart_pointer<rep>      base;
     typedef typename rep::size_type size_type;
 
 // allocators:
 
-    space_basic (const geo_basic<T,sequential>& omega = geo_basic<T,sequential>(), std::string approx = "");
+    space_basic (const geo_basic<T,sequential>& omega = (geo_basic<T,sequential>()), std::string approx = "");
 
 // accessors:
 
     void block  (std::string dom_name);
     void unblock(std::string dom_name);
-    void block  (const domain_basic<T,sequential>& dom);
-    void unblock(const domain_basic<T,sequential>& dom);
+    void block  (const domain_indirect_basic<sequential>& dom);
+    void unblock(const domain_indirect_basic<sequential>& dom);
 
     const distributor&  ownership() const;
     const communicator& comm() const;
     size_type           size() const;
-    size_type           par_size() const;
+    size_type           dis_size() const;
 
     const geo_basic<T,sequential>& get_geo() const;
     const element<T>&   get_element() const;
+    std::string get_stamp() const;
 
-    void set_par_dof (const geo_element& K, std::vector<size_type>& par_idof) const;
+    void get_dis_idof (const geo_element& K, std::vector<size_type>& dis_idof) const;
 
     const distributor& iu_ownership() const;
     const distributor& ib_ownership() const;
 
     bool      is_blocked (size_type     idof) const;
     size_type        iub (size_type     idof) const;
-    bool  par_is_blocked (size_type par_idof) const;
-    size_type    par_iub (size_type par_idof) const;
+    bool  dis_is_blocked (size_type dis_idof) const;
+    size_type    dis_iub (size_type dis_idof) const;
 
-    size_type idof2par_old_idof (size_type idof) const;
+    const distributor& ios_ownership() const;
+    size_type idof2ios_dis_idof (size_type idof) const;
+    size_type ios_idof2dis_idof (size_type ios_idof) const;
+
+    template <class Function>
+    T momentum (Function f, size_type idof) const;
+
+    array<size_type, sequential>
+    build_indirect_array (const geo_basic<T,sequential>& dom) const;
+
+// comparator:
+
+    bool operator== (const space_basic<T,sequential>& V2) const { return base::data().operator==(V2.data()); }
+    bool operator!= (const space_basic<T,sequential>& V2) const { return ! operator== (V2); }
+    friend bool are_compatible (const space_basic<T,sequential>& V1, const space_basic<T,sequential>& V2) {
+	return are_compatible (V1.data(), V2.data()); }
 };
 //>verbatim:
 template<class T>
@@ -383,6 +456,13 @@ space_basic<T,sequential>::ownership() const
 }
 template<class T>
 inline
+const distributor&
+space_basic<T,sequential>::ios_ownership() const
+{
+    return base::data().ios_ownership();
+}
+template<class T>
+inline
 const communicator&
 space_basic<T,sequential>::comm() const
 {
@@ -398,9 +478,9 @@ space_basic<T,sequential>::size() const
 template<class T>
 inline
 typename space_basic<T,sequential>::size_type
-space_basic<T,sequential>::par_size() const
+space_basic<T,sequential>::dis_size() const
 {
-    return base::data().par_size();
+    return base::data().dis_size();
 }
 template<class T>
 inline
@@ -418,17 +498,31 @@ space_basic<T,sequential>::get_element() const
 }
 template<class T>
 inline
-void
-space_basic<T,sequential>::set_par_dof (const geo_element& K, std::vector<size_type>& par_idof) const
+std::string
+space_basic<T,sequential>::get_stamp() const
 {
-    return base::data().set_par_dof (K, par_idof);
+    return base::data().get_stamp();
+}
+template<class T>
+inline
+void
+space_basic<T,sequential>::get_dis_idof (const geo_element& K, std::vector<size_type>& dis_idof) const
+{
+    return base::data().get_dis_idof (K, dis_idof);
 }
 template<class T>
 inline
 typename space_basic<T,sequential>::size_type
-space_basic<T,sequential>::idof2par_old_idof (size_type idof) const
+space_basic<T,sequential>::idof2ios_dis_idof (size_type idof) const
 {
-    return base::data().idof2par_old_idof (idof);
+    return base::data().idof2ios_dis_idof (idof);
+}
+template<class T>
+inline
+typename space_basic<T,sequential>::size_type
+space_basic<T,sequential>::ios_idof2dis_idof (size_type ios_idof) const
+{
+    return base::data().ios_idof2dis_idof (ios_idof);
 }
 template<class T>
 inline
@@ -461,78 +555,87 @@ space_basic<T,sequential>::iub (size_type idof) const
 template<class T>
 inline
 bool
-space_basic<T,sequential>::par_is_blocked (size_type par_idof) const
+space_basic<T,sequential>::dis_is_blocked (size_type dis_idof) const
 {
-    return base::data().par_is_blocked (par_idof);
+    return base::data().dis_is_blocked (dis_idof);
 }
 template<class T>
 inline
 typename space_basic<T,sequential>::size_type
-space_basic<T,sequential>::par_iub (size_type par_idof) const
+space_basic<T,sequential>::dis_iub (size_type dis_idof) const
 {
-    return base::data().par_iub (par_idof);
+    return base::data().dis_iub (dis_idof);
 }
 template<class T>
 inline
 void
 space_basic<T,sequential>::block (std::string dom_name)
 {
-    return base::data().block (get_geo()[dom_name]);
+    return base::data().block (get_geo().get_domain_indirect(dom_name));
 }
 template<class T>
 inline
 void
 space_basic<T,sequential>::unblock (std::string dom_name)
 {
-    return base::data().unblock (get_geo()[dom_name]);
+    return base::data().unblock (get_geo().get_domain_indirect(dom_name));
 }
 template<class T>
 inline
 void
-space_basic<T,sequential>::block (const domain_basic<T,sequential>& dom)
+space_basic<T,sequential>::block (const domain_indirect_basic<sequential>& dom)
 {
     return base::data().block (dom);
 }
 template<class T>
 inline
 void
-space_basic<T,sequential>::unblock (const domain_basic<T,sequential>& dom)
+space_basic<T,sequential>::unblock (const domain_indirect_basic<sequential>& dom)
 {
     return base::data().unblock (dom);
 }
+template<class T>
+template <class Function>
+inline
+T
+space_basic<T,sequential>::momentum (Function f, size_type idof) const
+{
+    return base::data().momentum (f, idof);
+}
 // ---------------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
 //<verbatim:
 template <class T>
-class space_basic<T,distributed> : public smart_pointer<space_mpi_rep<T> > {
+class space_basic<T,distributed> : public smart_pointer<space_rep<T,distributed> > {
 public:
 
 // typedefs:
 
-    typedef space_mpi_rep<T>        rep;
-    typedef smart_pointer<rep>      base;
-    typedef typename rep::size_type size_type;
+    typedef space_rep<T,distributed> rep;
+    typedef smart_pointer<rep>       base;
+    typedef typename rep::size_type  size_type;
 
 // allocators:
 
-    space_basic (const geo_basic<T,distributed>& omega = geo_basic<T,distributed>(), std::string approx = "");
+    space_basic (const geo_basic<T,distributed>& omega = (geo_basic<T,distributed>()), std::string approx = "");
 
 // accessors:
 
     void block  (std::string dom_name);
     void unblock(std::string dom_name);
-    void block  (const domain_basic<T,distributed>& dom);
-    void unblock(const domain_basic<T,distributed>& dom);
+    void block  (const domain_indirect_basic<distributed>& dom);
+    void unblock(const domain_indirect_basic<distributed>& dom);
 
     const distributor&  ownership() const;
     const communicator& comm() const;
     size_type           size() const;
-    size_type           par_size() const;
+    size_type           dis_size() const;
 
     const geo_basic<T,distributed>& get_geo() const;
     const element<T>&   get_element() const;
+    std::string get_stamp() const;
 
-    void set_par_dof (const geo_element& K, std::vector<size_type>& par_idof) const;
+    void get_dis_idof (const geo_element& K, std::vector<size_type>& dis_idof) const;
 
     const distributor& iu_ownership() const;
     const distributor& ib_ownership() const;
@@ -540,10 +643,25 @@ public:
     bool      is_blocked (size_type     idof) const;
     size_type        iub (size_type     idof) const;
 
-    bool  par_is_blocked (size_type par_idof) const;
-    size_type    par_iub (size_type par_idof) const;
+    bool  dis_is_blocked (size_type dis_idof) const;
+    size_type    dis_iub (size_type dis_idof) const;
 
-    size_type idof2par_old_idof         (size_type idof) const;
+    const distributor& ios_ownership() const;
+    size_type idof2ios_dis_idof (size_type idof) const;
+    size_type ios_idof2dis_idof (size_type ios_idof) const;
+
+    template <class Function>
+    T momentum (Function f, size_type idof) const;
+
+    array<size_type, distributed>
+    build_indirect_array (const geo_basic<T,distributed>& dom) const;
+
+// comparator:
+
+    bool operator== (const space_basic<T,distributed>& V2) const { return base::data().operator==(V2.data()); }
+    bool operator!= (const space_basic<T,distributed>& V2) const { return ! operator== (V2); }
+    friend bool are_compatible (const space_basic<T,distributed>& V1, const space_basic<T,distributed>& V2) {
+	return are_compatible (V1.data(), V2.data()); }
 };
 //>verbatim:
 
@@ -562,6 +680,13 @@ space_basic<T,distributed>::ownership() const
 }
 template<class T>
 inline
+const distributor&
+space_basic<T,distributed>::ios_ownership() const
+{
+    return base::data().ios_ownership();
+}
+template<class T>
+inline
 const communicator&
 space_basic<T,distributed>::comm() const
 {
@@ -577,9 +702,9 @@ space_basic<T,distributed>::size() const
 template<class T>
 inline
 typename space_basic<T,distributed>::size_type
-space_basic<T,distributed>::par_size() const
+space_basic<T,distributed>::dis_size() const
 {
-    return base::data().par_size();
+    return base::data().dis_size();
 }
 template<class T>
 inline
@@ -597,17 +722,31 @@ space_basic<T,distributed>::get_element() const
 }
 template<class T>
 inline
-void
-space_basic<T,distributed>::set_par_dof (const geo_element& K, std::vector<size_type>& par_idof) const
+std::string
+space_basic<T,distributed>::get_stamp() const
 {
-    return base::data().set_par_dof (K, par_idof);
+    return base::data().get_stamp();
+}
+template<class T>
+inline
+void
+space_basic<T,distributed>::get_dis_idof (const geo_element& K, std::vector<size_type>& dis_idof) const
+{
+    return base::data().get_dis_idof (K, dis_idof);
 }
 template<class T>
 inline
 typename space_basic<T,distributed>::size_type
-space_basic<T,distributed>::idof2par_old_idof (size_type idof) const
+space_basic<T,distributed>::idof2ios_dis_idof (size_type idof) const
 {
-    return base::data().idof2par_old_idof (idof);
+    return base::data().idof2ios_dis_idof (idof);
+}
+template<class T>
+inline
+typename space_basic<T,distributed>::size_type
+space_basic<T,distributed>::ios_idof2dis_idof (size_type ios_idof) const
+{
+    return base::data().ios_idof2dis_idof (ios_idof);
 }
 template<class T>
 inline
@@ -640,47 +779,77 @@ space_basic<T,distributed>::iub (size_type idof) const
 template<class T>
 inline
 bool
-space_basic<T,distributed>::par_is_blocked (size_type par_idof) const
+space_basic<T,distributed>::dis_is_blocked (size_type dis_idof) const
 {
-    return base::data().par_is_blocked (par_idof);
+    return base::data().dis_is_blocked (dis_idof);
 }
 template<class T>
 inline
 typename space_basic<T,distributed>::size_type
-space_basic<T,distributed>::par_iub (size_type par_idof) const
+space_basic<T,distributed>::dis_iub (size_type dis_idof) const
 {
-    return base::data().par_iub (par_idof);
+    return base::data().dis_iub (dis_idof);
 }
 template<class T>
 inline
 void
 space_basic<T,distributed>::block (std::string dom_name)
 {
-    return base::data().block (get_geo()[dom_name]);
+    return base::data().block (get_geo().get_domain_indirect(dom_name));
 }
 template<class T>
 inline
 void
 space_basic<T,distributed>::unblock (std::string dom_name)
 {
-    return base::data().unblock (get_geo()[dom_name]);
+    return base::data().unblock (get_geo().get_domain_indirect(dom_name));
 }
 template<class T>
 inline
 void
-space_basic<T,distributed>::block (const domain_basic<T,distributed>& dom)
+space_basic<T,distributed>::block (const domain_indirect_basic<distributed>& dom)
 {
-    warning_macro ("block domain "<<dom.name());
     base::data().block (dom);
 }
 template<class T>
 inline
 void
-space_basic<T,distributed>::unblock (const domain_basic<T,distributed>& dom)
+space_basic<T,distributed>::unblock (const domain_indirect_basic<distributed>& dom)
 {
     base::data().unblock (dom);
 }
+template<class T>
+template <class Function>
+inline
+T
+space_basic<T,distributed>::momentum (Function f, size_type idof) const
+{
+    return base::data().momentum (f, idof);
+}
 #endif // _RHEOLEF_HAVE_MPI
 
+// only valid when M=sequential or M=distributed => use a macro
+#define _RHEOLEF_space_build_indirect_array(M)						\
+template<class T>									\
+inline											\
+array<typename space_basic<T,M>::size_type, M>						\
+space_basic<T,M>::build_indirect_array (const geo_basic<T,M>& dom) const		\
+{											\
+    if (dom.data().variant() == geo_abstract_base_rep<T>::geo_domain_indirect) {	\
+      const geo_domain_indirect_rep<T,M>& dom_rep					\
+       = dynamic_cast<const geo_domain_indirect_rep<T,M>&>(dom.data());			\
+      return base::data().build_indirect_array (dom_rep.get_indirect());		\
+    }											\
+    error_macro ("build_indirect_array: unsupported non domain_indirect geo variant");	\
+    return array<size_type, M>(); /* not  reached */					\
+}
+_RHEOLEF_space_build_indirect_array(sequential)
+
+#ifdef _RHEOLEF_HAVE_MPI
+_RHEOLEF_space_build_indirect_array(distributed)
+#endif // _RHEOLEF_HAVE_MPI
+
+#undef _RHEOLEF_space_build_indirect_array
+
 } // namespace rheolef
 #endif // _RHEOLEF_SPACE_H
