@@ -33,7 +33,7 @@ cube-10-dom-v2
 "
 
 for geo in $L; do
-  loop_mpirun "./field_blocked_tst ${SRCDIR}/$geo 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/field_blocked-$geo.field - >/dev/null"
+  loop_mpirun "./field_blocked_tst ${SRCDIR}/$geo 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate-$geo-P1.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
