@@ -22,9 +22,9 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-  environment parallel(argc, argv);
-  geo omega; pcin >> omega;
-  space Vh (omega, "P1");
+  environment distributed(argc, argv);
+  geo omega (argv[1]);
+  space Vh (omega, argv[2]);
   field fh (Vh, 1.0);
-  pcout << fh;
+  dcout << fh;
 }
