@@ -29,10 +29,15 @@ status=0
 L="
 line-dom-v2
 carre-100-dom-v2
+carre-q-10-dom-v2
 cube-10-dom-v2
+cube-P-5-dom-v2
+cube-H-5-dom-v2
 "
 for geo in $L; do
-  loop_mpirun "./field_tst < ${SRCDIR}/$geo.geo 2>/dev/null >/dev/null"
-  if test $? -ne 0; then status=1; fi
+  for Pk in P1 P0 P1d; do
+    loop_mpirun "./field_tst ${SRCDIR}/$geo.geo $Pk 2>/dev/null >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
 done
 exit $status
