@@ -36,7 +36,7 @@ cube-gmsh-v2
 "
 
 for geo in $L; do
-  loop_mpirun "./form_mult_field_tst $SRCDIR/$geo 1e-10 2>/dev/null | diff -w -B form_mult_field-$geo.field - >/dev/null"
+  loop_mpirun "./form_mult_field_tst $SRCDIR/$geo 1e-10 2>/dev/null | diff -w -B form_mult_field-$geo-P1.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
