@@ -22,11 +22,7 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-  environment parallel(argc, argv);
-  warning_macro ("main[1] get...");
+  environment distributed(argc, argv);
   geo omega (argv[1]);
-  warning_macro ("main[2] get: size="<<omega.size());
-  warning_macro ("main[2] put...");
-  pcout << omega;
-  warning_macro ("main[3] done");
+  dcout << omega;
 }
