@@ -23,8 +23,12 @@ using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv)
 {
-    environment parallel(argc, argv);
+    environment distributed(argc, argv);
     geo_basic<Float,sequential> omega;
-    pcin >> omega;
-    pcout << omega;
+    if (argc > 1) {
+      omega.load (argv[1]);
+    } else {
+      dcin >> omega;
+    }
+    dcout << omega;
 }
