@@ -25,11 +25,11 @@ using namespace std;
 size_t N;
 Float f (const point& x) { return 1+(0.5/N)*(x[0]*(1-x[0])+x[1]*(1-x[1])+x[2]*(1-x[2])); }
 int main(int argc, char**argv) {
-  environment parallel(argc, argv);
-  Float prec = (argc > 3) ? atof(argv[3]) : 1e-10;
+  environment distributed(argc, argv);
   geo omega (argv[1]);
-  space Vh (omega, "P1");
+  space Vh (omega, argv[2]);
+  Float prec = (argc > 3) ? atof(argv[3]) : 1e-10;
   N = omega.dimension();
   field fh = interpolate(Vh, f);
-  pcout << setprecision(15) << compose(rounder(prec),fh);
+  dcout << setprecision(15) << compose(rounder(prec),fh);
 }
