@@ -33,8 +33,10 @@ cube-10-dom-v2
 "
 
 for geo in $L; do
-  loop_mpirun "./interpolate_tst ${SRCDIR}/$geo 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/field_blocked-$geo.field - >/dev/null"
-  if test $? -ne 0; then status=1; fi
+  for Pk in P1 P0 P1d; do
+    loop_mpirun "./interpolate_tst ${SRCDIR}/$geo $Pk 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate-$geo-$Pk.field - >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
 done
 
 exit $status
