@@ -23,16 +23,11 @@ using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv)
 {
-    environment parallel(argc, argv);
+    environment distributed(argc, argv);
     size_t n;
-warning_macro ("main[0]");
-    pcin >> n;
-warning_macro ("main[1] n="<<n);
+    dcin >> n;
     polymorphic_array<geo_element> x(n);
-warning_macro ("main[2]");
-    pcin >> x;
-warning_macro ("main[3]");
-    pcout << x.par_size() << endl 
+    dcin >> x;
+    dcout << x.dis_size() << endl 
           << x            << endl;
-warning_macro ("main[F]");
 }
