@@ -21,7 +21,14 @@
 template <class T>
 struct rounder_type : std::unary_function<T,T> {
   rounder_type (const T& prec) : _prec(prec) {}
-  T operator() (const T& x) const { return _prec*T((long long int)(x/_prec+0.5)); }
+  T operator() (const T& x) const { 
+     T value = _prec*round(x/_prec);
+     if (1+value == 1) value = 0;
+     return value;
+  }
+#ifdef TO_CLEAN
+  //T operator() (const T& x) const { return _prec*T((long long int)(x/_prec+0.5)); }
+#endif // TO_CLEAN
   T _prec;
 };
 template <class T>
