@@ -22,8 +22,8 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-  environment parallel(argc, argv);
+  environment distributed(argc, argv);
   geo omega (argv[1]);
-  space Vh (omega, "P1");
+  space Vh (omega, argv[2]);
   return 0;
 }
