@@ -25,13 +25,31 @@ NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
+
 L="
 line-dom-v2
 carre-100-dom-v2
+carre-q-10-dom-v2
 cube-10-dom-v2
+cube-P-5-dom-v2
+cube-H-5-dom-v2
 "
 for geo in $L; do
-  loop_mpirun "./space_tst ${SRCDIR}/$geo.geo 2>/dev/null >/dev/null"
-  if test $? -ne 0; then status=1; fi
+  for Pk in P1 P0 P1d; do
+    loop_mpirun "./space_tst ${SRCDIR}/$geo.geo $Pk 2>/dev/null >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
 done
+
+L="
+carre-tq-10-dom-v2
+extrude-TP-gmsh-dom-v2
+"
+for geo in $L; do
+  for Pk in P1 P0; do
+    loop_mpirun "./space_tst ${SRCDIR}/$geo.geo $Pk 2>/dev/null >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
+done
+
 exit $status
