@@ -173,10 +173,14 @@ def mayavi2_axis (view, option):
 
 def check_stereo_axis (view, option):
 
+    scene = view.engine.current_scene.scene
+
+    if option['axis']:
+        outline = Outline()
+        view.add_module(outline)
+        mayavi2_axis (view, option)
+
     if not option['view_2d']:
-    
-        scene  = view.engine.current_scene.scene
-        window = scene.render_window
 
         # select initial view:
         scene.isometric_view()
@@ -185,6 +189,7 @@ def check_stereo_axis (view, option):
 
         # enter directly in stereo, as typing '3' in the window:
         if option['stereo']:
+            window = scene.render_window
             window.stereo_render = True
             window.stereo_type   = 'anaglyph' ; # or 'red_blue'
             show_window = 0
@@ -195,11 +200,11 @@ def check_stereo_axis (view, option):
               except BadWindow:
                 pass
 
-    if option['axis']:
-        outline = Outline()
-        view.add_module(outline)
-        mayavi2_axis (view, option)
+    if option['view_2d']:
 
+        # select initial view:
+        scene.z_plus_view()
+    
 # --------------------------------------------------------------------------
 # geo visualization
 # --------------------------------------------------------------------------
@@ -237,9 +242,11 @@ def mayavi2_geo_domain (view, option, filename, dom_name, idx):
         n_vertex  = output.number_of_points
         n_element = output.number_of_cells
 	title = "%s : %d elements, %d vertices"%(dom_name, n_element, n_vertex)
-        title_text = Text(text=title, x_position=0.5, y_position=0.9)
+        title_text = Text(text=title)
+        title_text.x_position = 0.5
+        title_text.y_position = 0.9
         view.add_module(title_text)
-        title_text.property.font_size = 30
+        title_text.property.font_size = 15
         title_text.property.color = (0,0,0)
         title_text.property.justification = 'centered'
         title_text.property.font_family = 'times'
@@ -296,10 +303,10 @@ def mayavi2_geo_domain (view, option, filename, dom_name, idx):
         else:
           name = dom_name
         dom_text = Text(text=name)
-        dom_text.x_position = 0.02
-        dom_text.y_position = 0.02+idx*0.04
+        dom_text.x_position = 0.01
+        dom_text.y_position = 0.01+idx*0.04
         view.add_module(dom_text)
-        dom_text.property.font_size = 20
+        dom_text.property.font_size = 15
         dom_text.property.color = color
 	vtk_version = float(tvtk.Version().vtk_version[:3])
         if vtk_version > 5.1:
