@@ -43,12 +43,10 @@ struct mpi_polymorphic_scatter_init_t <PointerArray,Container1,Container2,Messag
     communicator comm = ownership.comm();
     size_type  my_proc = comm.rank();
     size_type  nproc   = comm.size();
-    size_type  idy_maxval = ownership.par_size();
-warning_macro ("scatter_init: nidx="<<idx.size());
+    size_type  idy_maxval = ownership.dis_size();
     // ------------------------------------------------------- 
     // 1) first count number of contributors to each processor
     // ------------------------------------------------------- 
-warning_macro ("scatter_init[1]: counting...");
     std::vector<size_type> msg_size(nproc, 0);
     std::vector<size_type> msg_mark(nproc, 0);
     std::vector<size_type> owner   (idx.size(), unset);
@@ -103,7 +101,6 @@ warning_macro ("scatter_init[1]: counting...");
         msg_mark [my_proc] = 0;
         send_nproc--;
     }
-warning_macro ("scatter_init[2]: n_local="<<n_local);
     // ----------------------------------------------------------------
     // 3) compute number of messages to be send to my_proc
     // ----------------------------------------------------------------
@@ -115,8 +112,6 @@ warning_macro ("scatter_init[2]: n_local="<<n_local);
 	work.begin().operator->(),
 	std::plus<size_type>());
     size_type receive_nproc = work [my_proc];
-
-warning_macro ("scatter_init[3]: receive_nproc="<<receive_nproc);
     // ----------------------------------------------------------------
     // 4) compute messages max size to be send to my_proc
     // ----------------------------------------------------------------
@@ -127,11 +122,9 @@ warning_macro ("scatter_init[3]: receive_nproc="<<receive_nproc);
 	work.begin().operator->(),
         mpi::maximum<size_type>());
     size_type receive_max_size = work [my_proc];
-warning_macro ("scatter_init[4]: receive_max_size="<<receive_max_size);
     // ----------------------------------------------------------------
     // 5) post receive: exchange the buffer adresses between processes
     // ----------------------------------------------------------------
-warning_macro ("scatter_init[5]: post_receive...");
     std::list<std::pair<size_type,mpi::request> > receive_waits;
     std::vector<std::pair<size_type,size_type> >  receive_data (
 	receive_nproc*receive_max_size, std::make_pair(unset, unset)); // pair(idx,variant)
@@ -146,21 +139,17 @@ warning_macro ("scatter_init[5]: post_receive...");
     // ---------------------------------------------------------------------------
     // 6) compute the send indexes
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[6]: compute the send indexes...");
     // comme idx est trie, on peut faire une copie de idx dans send_data
     // et du coup owner et send_data_ownership sont inutiles
     // TODO: ajouter le type k de la variante
     std::vector<std::pair<size_type,size_type> >  send_data (idx.size(), std::make_pair(unset, unset)); // pair(idx,variant)
-warning_macro ("scatter_init[6]: send_data.size="<<idx.size());
     for (size_type i = 0, n = idx.size(); i < n; i++) {
-warning_macro ("scatter_init[6]: send_data["<<i<<"]={"<<idx[i]<<",k="<<ptr[i].variant()<<"}");
         send_data[i].first  = idx[i];
         send_data[i].second = ptr[i].variant(); // the variant k of polymorphic_array[i]
     }
     // ---------------------------------------------------------------------------
     // 7) do send
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[7]: do send indexes...");
     std::list<std::pair<size_type,mpi::request> > send_waits;
     {
       size_type i_send = 0;
@@ -173,13 +162,6 @@ warning_macro ("scatter_init[7]: do send indexes...");
 	    tag_header, 
             send_data.begin().operator->() + i_start,  
             i_msg_size);
-#ifndef TO_CLEAN
-warning_macro ("scatter_init[7]: to_proc="<<iproc<<": send_data.size="<<i_msg_size);
-        for (size_type j = 0; j < i_msg_size; j++) {
-warning_macro ("scatter_init[7]: to_proc="<<iproc<<": send_data["<<j<<"]={"
-		<<send_data[i_start+j].first<<",k="<<send_data[i_start+j].second<<"}");
-        }
-#endif // TO_CLEAN
         send_waits.push_back(std::make_pair(i_send,i_req));
         i_send++;
         i_start += i_msg_size;
@@ -188,7 +170,6 @@ warning_macro ("scatter_init[7]: to_proc="<<iproc<<": send_data["<<j<<"]={"
     // ---------------------------------------------------------------------------
     // 8) wait on receives indexes
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[8]: wait on receive indexes...");
     // note: for wait_all, build an iterator adapter that scan the pair.second in [index,request]
     // and then get an iterator in the pair using iter.base(): retrive the corresponding index
     // for computing the position in the receive.data buffer
@@ -234,13 +215,11 @@ warning_macro ("scatter_init[8]: wait on receive indexes...");
         receive_size [i_receive] = i_msg_size;
         receive_total_size += i_msg_size;
         receive_waits.erase (i_pair_ptr);
-warning_macro ("scatter_init[8]: from_proc="<<iproc<<": receive_data.size="<<i_msg_size);
         size_type i_start = i_receive*receive_max_size;
         for (size_type j = 0; j < i_msg_size; j++) {
             size_type idx_j = receive_data [i_start + j].first;
             size_type k     = receive_data [i_start + j].second; // k=variant
             receive_data_poly[k][i_start + receive_size_poly[k][i_receive]++] = idx_j;
-warning_macro ("scatter_init[8]: from_proc="<<iproc<<": receive_data["<<j<<"]={"<<idx_j<<",k="<<k<<"}");
             receive_total_size_poly[k]++;
 	    if (! receive_proc_mark_poly[k][i_receive]) {
 	          receive_proc_mark_poly[k][i_receive] = 1;
@@ -249,23 +228,13 @@ warning_macro ("scatter_init[8]: from_proc="<<iproc<<": receive_data["<<j<<"]={"
 	    }
         }
     }
-warning_macro ("scatter_init[8]: receive_total_size="<<receive_total_size);
     // ---------------------------------------------------------------------------
     // 9) allocate the entire send(to) scatter context
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[9]: allocate the send(to) message...");
     to.resize (receive_total_size_poly, receive_nproc_poly);
-
-#ifndef TO_CLEAN
-    for (size_type k = 0; k < _n_variant; k++) {
-      warning_macro ("k="<<k<<", receive_total_size="<<
-    	receive_total_size_poly[k] << ", receive_nproc="<< receive_nproc_poly[k]);
-    }
-#endif // TO_CLEAN
     // ---------------------------------------------------------------------------
     // 10) compute the permutation of values that gives the sorted source[] sequence
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[10]: compute the permutation...");
     boost::array<std::vector<size_type>,_n_variant> perm;
     for (size_type k = 0; k < _n_variant; k++) {
       // init: perm[i] = i
@@ -280,8 +249,7 @@ warning_macro ("scatter_init[10]: compute the permutation...");
     // ---------------------------------------------------------------------------
     // 11) Computes the receive compresed message pattern for send(to)
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[11]: compute the receive compressed msg for send(to)...");
-    size_type first_par_idx = ownership.first_index();
+    size_type first_dis_idx = ownership.first_index();
     for (size_type k = 0; k < _n_variant; k++) {
       msg_to_context (
         perm[k].begin(),
@@ -290,7 +258,7 @@ warning_macro ("scatter_init[11]: compute the receive compressed msg for send(to
         receive_size_poly[k].begin(),
         receive_data_poly[k].begin(),
         receive_max_size,  // TODO: not optimal, could depend upon k: receive_max_size_poly[k]
-        first_par_idx,
+        first_dis_idx,
         to.procs[k].begin(),
         to.starts[k].begin(),
         to.indices[k].begin());
@@ -298,18 +266,10 @@ warning_macro ("scatter_init[11]: compute the receive compressed msg for send(to
     // ---------------------------------------------------------------------------
     // 12) allocate the entire receive(from) scatter context
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[12]: allocate the send(to) context...");
     from.resize(send_total_size_poly, send_nproc_poly);
-#ifndef TO_CLEAN
-    for (size_type k = 0; k < _n_variant; k++) {
-      warning_macro ("k="<<k<<", send_total_size="<<
-    	send_total_size_poly[k] << ", send_nproc="<< send_nproc_poly[k]);
-    }
-#endif // TO_CLEAN
     // ---------------------------------------------------------------------------
     // 13) Computes the receive compresed message pattern for receive(from)
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[13]: compress the recv(from) msg pattern...");
     boost::array<std::vector<size_type>,_n_variant> proc2from_proc;
     for (size_type k = 0; k < _n_variant; k++) {
       proc2from_proc[k].resize (nproc);
@@ -324,7 +284,6 @@ warning_macro ("scatter_init[13]: compress the recv(from) msg pattern...");
     // 14) Computes the receive compresed message indices for receive(from)
     // ---------------------------------------------------------------------------
     // assume that indices are sorted by increasing order
-warning_macro ("scatter_init[14]: compress the recv(from) msg indices...");
     for (size_type k = 0; k < _n_variant; k++) {
       std::vector<size_type> start (from.starts[k].size());
       copy (from.starts[k].begin(), from.starts[k].end(), start.begin());
@@ -341,7 +300,6 @@ warning_macro ("scatter_init[14]: compress the recv(from) msg indices...");
     // ---------------------------------------------------------------------------
     // 15) wait on sends
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[15]: wait on sends...");
     request_iterator iter_s_waits (send_waits.begin(), select2nd<size_type,mpi::request>()),
                      last_s_waits (send_waits.end(),   select2nd<size_type,mpi::request>());
     mpi::wait_all (iter_s_waits, last_s_waits);
@@ -349,17 +307,16 @@ warning_macro ("scatter_init[15]: wait on sends...");
     // 16) Computes the receive compresed message local pattern,
     // i.e. the only part that does not requires communication.
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[16]: local msg pattern...");
     from.local_slots.resize(n_local);
     to.local_slots.resize(n_local);
-    size_type last_par_idx = ownership.last_index();
+    size_type last_dis_idx = ownership.last_index();
     msg_local_context (
 	idx.begin(),
     	idx.end(),
     	idy.begin(),
     	idy_maxval,
-        first_par_idx,
-    	last_par_idx,
+        first_dis_idx,
+    	last_dis_idx,
         to.local_slots.begin(),
         to.local_slots.end(),
         from.local_slots.begin());
@@ -367,7 +324,6 @@ warning_macro ("scatter_init[16]: local msg pattern...");
     // ---------------------------------------------------------------------------
     // 17) Optimize local exchanges during gatter/scatter
     // ---------------------------------------------------------------------------
-warning_macro ("scatter_init[17]: optimize local exchanges...");
     bool has_opt = msg_local_optimize (
         to.local_slots.begin(),
         to.local_slots.end(),
@@ -381,7 +337,6 @@ warning_macro ("scatter_init[17]: optimize local exchanges...");
         from.local_copy_start  = from.local_slots[0];
         from.local_copy_length = n_local;
     }
-warning_macro ("scatter_init done");
   }
 };
 #endif // _RHEOLEF_HAVE_MPI
