@@ -26,8 +26,12 @@
 #include "rheolef/polymorphic_data_vector.h"
 #include "rheolef/polymorphic_data_map.h"
 #include "rheolef/polymorphic_map.h"
+
+#ifdef _RHEOLEF_HAVE_MPI
 #include "rheolef/polymorphic_scatter_message.h"
 #include "rheolef/mpi_scatter_init.h"
+#endif // _RHEOLEF_HAVE_MPI
+
 #include <list>
 
 namespace rheolef {
@@ -228,8 +232,8 @@ public:
 
 // allocators:
 
-    polymorphic_array_seq_rep (const distributor& ownership);
     polymorphic_array_seq_rep (size_type loc_size = 0);
+    polymorphic_array_seq_rep (const distributor& ownership);
     polymorphic_array_seq_rep (const array_seq_rep<T>& x);
     void resize (const distributor& ownership);
     void resize (size_type loc_size);
@@ -237,7 +241,7 @@ public:
 // accessors
 
   size_type     size() const { return _ptr.size(); }
-  size_type par_size() const { return size(); }
+  size_type dis_size() const { return size(); }
   reference       operator[] (size_type index)       { return       reference (*this, index); }
   const_reference operator[] (size_type index) const { return const_reference (_ptr[index]); }
   size_type       variant    (size_type index) const { return _ptr[index].variant(); }
@@ -249,15 +253,15 @@ public:
   const communicator&  comm() const { return ownership().comm(); }
 
 #define _RHEOLEF_set(z,k,unused)                            			\
-  void set    (size_type index, const T##k& value) { assign (index, value); }
+  void set_dis_entry (size_type index, const T##k& value) { assign (index, value); }
   BOOST_PP_REPEAT(N, _RHEOLEF_set, ~)
 #undef _RHEOLEF_set
 
 // i/o
 
-  iparstream& get (iparstream& ips);
-  oparstream& put (oparstream& ops) const;
-  template <class PutFunction> oparstream& put (oparstream& opsa, PutFunction put_element) const;
+  idiststream& get_values (idiststream& ips);
+  odiststream& put_values (odiststream& ops) const;
+  template <class PutFunction> odiststream& put_values (odiststream& opsa, PutFunction put_element) const;
   void dump (std::string name) const;
 
 // internal:
@@ -307,16 +311,19 @@ public:
 
 // allocators:
 
+#ifdef TO_CLEAN
+  polymorphic_array_mpi_rep (size_type dis_size = 0, size_type loc_size = distributor::decide); 
+  void resize (size_type dis_size = 0, size_type loc_size = distributor::decide);
+#endif // TO_CLEAN
+
   polymorphic_array_mpi_rep (const distributor& ownership);
-  polymorphic_array_mpi_rep (size_type par_size = 0, size_type loc_size = distributor::decide); 
+  void resize               (const distributor& ownership);
   polymorphic_array_mpi_rep (const polymorphic_array_mpi_rep<T,V,N>& x);
-  void resize (const distributor& ownership);
-  void resize (size_type par_size = 0, size_type loc_size = distributor::decide);
 
 // accessors & modifiers:
 
   size_type size()     const { return polymorphic_array_seq_rep<T,V,N>::size(); }
-  size_type par_size() const { return ownership().par_size(); }
+  size_type dis_size() const { return ownership().dis_size(); }
 
   const distributor&  ownership() const { return polymorphic_array_seq_rep<T,V,N>::ownership(); }
   const communicator& comm() const { return ownership().comm(); }
@@ -333,12 +340,12 @@ public:
         iterator end   ()       { return seq::end(); }
 
 #define _RHEOLEF_set(z,k,unused)                            	\
-  void set    (size_type par_index, const T##k& value);
+  void set_dis_entry (size_type dis_index, const T##k& value);
   BOOST_PP_REPEAT(N, _RHEOLEF_set, ~)
 #undef _RHEOLEF_set
 
-  void assembly_begin ();
-  void assembly_end ();
+  void dis_entry_assembly_begin ();
+  void dis_entry_assembly_end ();
 
   void repartition (					      // old_numbering for *this
         const array_mpi_rep<size_type>&     partition,	      // old_ownership
@@ -347,16 +354,16 @@ public:
         array_mpi_rep<size_type>&           new_numbering) const; // old_ownership
 
   template<class Set>
-  void scatter (const Set& ext_idx_set, polymorphic_map_rep<T,V,N>& ext_idx_map) const;
+  void get_dis_entry (const Set& ext_idx_set, polymorphic_map_rep<T,V,N>& ext_idx_map) const;
 
 // i/o
 
-  iparstream& get (iparstream& ips);
-  oparstream& put (oparstream& ops) const;
+  idiststream& get_values (idiststream& ips);
+  odiststream& put_values (odiststream& ops) const;
   template <class Permutation>
-  oparstream& permuted_put (oparstream& ops, const Permutation& perm) const;
+  odiststream& permuted_put_values (odiststream& ops, const Permutation& perm) const;
   template <class Permutation, class PutFunction>
-  oparstream& permuted_put (oparstream& ops, const Permutation& perm,
+  odiststream& permuted_put_values (odiststream& ops, const Permutation& perm,
 				PutFunction put_element) const;
   void dump (std::string name) const;
 
@@ -403,14 +410,14 @@ public:
 // constructors:
 
     polymorphic_array (size_type n = 0);
+    void resize       (size_type n);
     polymorphic_array (const distributor& ownership);
-    void resize (size_type n);
-    void resize (const distributor& ownership);
+    void resize       (const distributor& ownership);
 
 // accessors & modifiers:
 
     size_type       size () const;
-    size_type       par_size() const;
+    size_type       dis_size() const;
     reference       operator[] (size_type i);
     const_reference operator[] (size_type i) const;
     const_iterator begin () const;
@@ -423,16 +430,16 @@ public:
 
 // i/o:
 
-    iparstream& get (iparstream& ips);
-    oparstream& put (oparstream& ops) const;
-    template <class PutFunction> oparstream& put (oparstream& ops, PutFunction put_element) const;
+    idiststream& get_values (idiststream& ips);
+    odiststream& put_values (odiststream& ops) const;
+    template <class PutFunction> odiststream& put_values (odiststream& ops, PutFunction put_element) const;
     void dump (std::string name) const;
 };
 template <class T, class V>
-oparstream& operator<< (oparstream& ops, const polymorphic_array<T,sequential,V>& x);
+odiststream& operator<< (odiststream& ops, const polymorphic_array<T,sequential,V>& x);
 
 template <class T, class V>
-iparstream& operator>> (iparstream& ips, polymorphic_array<T,sequential,V>& x);
+idiststream& operator>> (idiststream& ips, polymorphic_array<T,sequential,V>& x);
 //>polymorphic_array:
 
 template <class T, class V>
@@ -471,9 +478,9 @@ polymorphic_array<T,sequential,V>::size () const
 template <class T, class V>
 inline
 typename polymorphic_array<T,sequential,V>::size_type
-polymorphic_array<T,sequential,V>::par_size () const
+polymorphic_array<T,sequential,V>::dis_size () const
 {
-    return base::data().par_size();
+    return base::data().dis_size();
 }
 template <class T, class V>
 inline
@@ -533,25 +540,25 @@ polymorphic_array<T,sequential,V>::comm() const
 }
 template <class T, class V>
 inline
-iparstream&
-polymorphic_array<T,sequential,V>::get(iparstream& ips)
+idiststream&
+polymorphic_array<T,sequential,V>::get_values(idiststream& ips)
 {
-    return base::data().get(ips);
+    return base::data().get_values(ips);
 }
 template <class T, class V>
 template <class PutFunction>
 inline
-oparstream&
-polymorphic_array<T,sequential,V>::put(oparstream& ops, PutFunction put_element) const
+odiststream&
+polymorphic_array<T,sequential,V>::put_values(odiststream& ops, PutFunction put_element) const
 {
-    return base::data().put (ops, put_element);
+    return base::data().put_values (ops, put_element);
 }
 template <class T, class V>
 inline
-oparstream&
-polymorphic_array<T,sequential,V>::put(oparstream& ops) const
+odiststream&
+polymorphic_array<T,sequential,V>::put_values(odiststream& ops) const
 {
-    return base::data().put(ops);
+    return base::data().put_values(ops);
 }
 template <class T, class V>
 inline
@@ -562,15 +569,15 @@ polymorphic_array<T,sequential,V>::dump(std::string name) const
 }
 template <class T, class V>
 inline
-oparstream& 
-operator<< (oparstream& ops, const polymorphic_array<T,sequential,V>& x) {
-     return x.put (ops);
+odiststream& 
+operator<< (odiststream& ops, const polymorphic_array<T,sequential,V>& x) {
+     return x.put_values (ops);
 }
 template <class T, class V>
 inline
-iparstream& 
-operator>> (iparstream& ips, polymorphic_array<T,sequential,V>& x) {
-     return x.get (ips);
+idiststream& 
+operator>> (idiststream& ips, polymorphic_array<T,sequential,V>& x) {
+     return x.get_values(ips);
 }
 // -------------------------------------------------------------
 // wrapper class: distributed polymorphic_array 
@@ -597,15 +604,17 @@ public:
 
 // constructors:
 
+#ifdef TO_CLEAN
     polymorphic_array (size_type n = 0);
-    polymorphic_array (const distributor& ownership);
-    void resize (size_type n);
-    void resize (const distributor& ownership);
+    void resize       (size_type n);
+#endif // TO_CLEAN
+    polymorphic_array (const distributor& ownership = distributor());
+    void resize       (const distributor& ownership);
 
 // accessors & modifiers:
 
     size_type       size () const;
-    size_type       par_size () const;
+    size_type       dis_size () const;
     reference       operator[] (size_type i);
     const_reference operator[] (size_type i) const;
     const_iterator begin () const;
@@ -616,6 +625,9 @@ public:
     const distributor&  ownership() const;
     const communicator& comm() const;
 
+    void dis_entry_assembly_begin ();
+    void dis_entry_assembly_end ();
+
     void repartition (					      // old_numbering for *this
         const array<size_type,distributed>& partition,	      // old_ownership
         polymorphic_array<T,distributed,V>& new_array,	      // new_ownership (created)
@@ -623,26 +635,27 @@ public:
         array<size_type,distributed>&       new_numbering) const; // old_ownership
 
   template<class Set>
-  void scatter (const Set& ext_idx_set, polymorphic_map<T,V>& ext_idx_map) const;
+  void get_dis_entry (const Set& ext_idx_set, polymorphic_map<T,V>& ext_idx_map) const;
 
 // i/o:
 
-    iparstream& get (iparstream& ips);
-    oparstream& put (oparstream& ops) const;
+    idiststream& get_values (idiststream& ips);
+    odiststream& put_values (odiststream& ops) const;
     template <class Permutation>
-    oparstream& permuted_put (oparstream& ops, const Permutation& perm) const;
+    odiststream& permuted_put_values (odiststream& ops, const Permutation& perm) const;
     template <class Permutation, class PutFunction>
-    oparstream& permuted_put (oparstream& ops, const Permutation& perm,
+    odiststream& permuted_put_values (odiststream& ops, const Permutation& perm,
 				PutFunction put_element) const;
     void dump (std::string name) const;
 };
 template <class T, class V>
-oparstream& operator<< (oparstream& ops, const polymorphic_array<T,distributed,V>& x);
+odiststream& operator<< (odiststream& ops, const polymorphic_array<T,distributed,V>& x);
 
 template <class T, class V>
-iparstream& operator>> (iparstream& ips, polymorphic_array<T,distributed,V>& x);
+idiststream& operator>> (idiststream& ips, polymorphic_array<T,distributed,V>& x);
 //>polymorphic_array:
 
+#ifdef TO_CLEAN
 template <class T, class V>
 inline
 polymorphic_array<T,distributed,V>::polymorphic_array (size_type n)
@@ -651,17 +664,18 @@ polymorphic_array<T,distributed,V>::polymorphic_array (size_type n)
 }
 template <class T, class V>
 inline
-polymorphic_array<T,distributed,V>::polymorphic_array (const distributor& ownership)
- : base (new_macro(rep(ownership)))
-{
-}
-template <class T, class V>
-inline
 void
 polymorphic_array<T,distributed,V>::resize (size_type n)
 {
     return base::data().resize(n);
 }
+#endif // TO_CLEAN
+template <class T, class V>
+inline
+polymorphic_array<T,distributed,V>::polymorphic_array (const distributor& ownership)
+ : base (new_macro(rep(ownership)))
+{
+}
 template <class T, class V>
 inline
 void
@@ -679,9 +693,9 @@ polymorphic_array<T,distributed,V>::size () const
 template <class T, class V>
 inline
 typename polymorphic_array<T,distributed,V>::size_type
-polymorphic_array<T,distributed,V>::par_size () const
+polymorphic_array<T,distributed,V>::dis_size () const
 {
-    return base::data().par_size();
+    return base::data().dis_size();
 }
 template <class T, class V>
 inline
@@ -741,38 +755,52 @@ polymorphic_array<T,distributed,V>::comm() const
 }
 template <class T, class V>
 inline
-iparstream&
-polymorphic_array<T,distributed,V>::get(iparstream& ips)
+idiststream&
+polymorphic_array<T,distributed,V>::get_values(idiststream& ips)
 {
-    return base::data().get(ips);
+    return base::data().get_values(ips);
 }
 template <class T, class V>
 inline
-oparstream&
-polymorphic_array<T,distributed,V>::put(oparstream& ops) const
+odiststream&
+polymorphic_array<T,distributed,V>::put_values(odiststream& ops) const
 {
-    return base::data().put(ops);
+    return base::data().put_values(ops);
+}
+template <class T, class V>
+inline
+void
+polymorphic_array<T,distributed,V>::dis_entry_assembly_begin ()
+{
+    return base::data().dis_entry_assembly_begin();
+}
+template <class T, class V>
+inline
+void
+polymorphic_array<T,distributed,V>::dis_entry_assembly_end ()
+{
+    return base::data().dis_entry_assembly_end();
 }
 template <class T, class V>
 template <class Permutation>
 inline
-oparstream&
-polymorphic_array<T,distributed,V>::permuted_put (
-    oparstream& ops, 
+odiststream&
+polymorphic_array<T,distributed,V>::permuted_put_values (
+    odiststream& ops, 
     const Permutation& perm) const
 {
-    return base::data().permuted_put (ops, perm);
+    return base::data().permuted_put_values (ops, perm);
 }
 template <class T, class V>
 template <class Permutation, class PutFunction>
 inline
-oparstream&
-polymorphic_array<T,distributed,V>::permuted_put (
-    oparstream& ops, 
+odiststream&
+polymorphic_array<T,distributed,V>::permuted_put_values (
+    odiststream& ops, 
     const Permutation& perm,
     PutFunction put_element) const
 {
-    return base::data().permuted_put (ops, perm, put_element);
+    return base::data().permuted_put_values (ops, perm, put_element);
 }
 template <class T, class V>
 inline
@@ -783,15 +811,15 @@ polymorphic_array<T,distributed,V>::dump(std::string name) const
 }
 template <class T, class V>
 inline
-oparstream& 
-operator<< (oparstream& ops, const polymorphic_array<T,distributed,V>& x) {
-     return x.put (ops);
+odiststream& 
+operator<< (odiststream& ops, const polymorphic_array<T,distributed,V>& x) {
+     return x.put_values (ops);
 }
 template <class T, class V>
 inline
-iparstream& 
-operator>> (iparstream& ips, polymorphic_array<T,distributed,V>& x) {
-     return x.get (ips);
+idiststream& 
+operator>> (idiststream& ips, polymorphic_array<T,distributed,V>& x) {
+     return x.get_values (ips);
 }
 template <class T, class V>
 inline
@@ -812,11 +840,11 @@ template <class T, class V>
 template<class Set>
 inline
 void
-polymorphic_array<T,distributed,V>::scatter (
+polymorphic_array<T,distributed,V>::get_dis_entry (
 	const Set&            ext_idx_set,
 	polymorphic_map<T,V>& ext_idx_map) const
 {
-    base::data().scatter (ext_idx_set, ext_idx_map.data());
+    base::data().get_dis_entry (ext_idx_set, ext_idx_map.data());
 }
 #endif // _RHEOLEF_HAVE_MPI
 
