@@ -25,6 +25,10 @@
 #include "rheolef/vec.h"
 #include "rheolef/csr_vec_expr.h"
 #include "rheolef/vec_expr.h"
+#include "rheolef/vec_expr_ops.h"
 #include "rheolef/csr.h"
-#include "rheolef/par_inner_product.h"
+#include "rheolef/dis_inner_product.h"
+#include "rheolef/solver.h"
+#include "rheolef/pcg.h"
+#include "rheolef/eye.h"
 #endif // _RHEOLEF_SKIT_H
