@@ -22,19 +22,16 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-    environment parallel(argc, argv);
+    environment distributed(argc, argv);
     size_t n = (argc < 2) ? 5 : atoi(argv[1]);
     asr<Float> a(n,n);
     size_t first = a.row_first_index();
     size_t last  = a.row_last_index();
     for (size_t i = 0; i < n; i++) {
     	if (i >= first && i < last) {
-	    a.entry (i, i) = 1000+i+0.5;
+	    a.dis_entry (i, i) = 1000+i+0.5;
         }
     }
-    a.assembly();
-    pcout << a.par_nrow() << " "
-          << a.par_ncol() << " "
-	  << a.par_nnz()  << endl
-	  << a ;
+    a.dis_entry_assembly();
+    dcout << a;
 }
