@@ -21,22 +21,13 @@
 # include "rheolef/csr.h"
 using namespace rheolef;
 using namespace std;
-int main(int argc, char**argv)
-{
-    environment parallel(argc, argv);
-
-    unsigned int nrow;
-    unsigned int ncol;
-    pcin >> nrow >> ncol;
-    asr<Float> a1(nrow, ncol);
-    pcin >> a1;
-
-    csr<Float> a(a1);
-
+int main(int argc, char**argv) {
+    environment distributed(argc, argv);
+    csr<Float> a;
+    dcin >> a;
     vec<Float> x (a.col_ownership(), 1.0);
     vec<Float> y (a.row_ownership(), 1e+38);
-    a.mult(x, y);
-
-    pcout << y.par_size() << endl
+    a.mult (x, y);
+    dcout << y.dis_size() << endl
           << y            << endl;
 }
