@@ -21,22 +21,9 @@
 # include "rheolef/csr.h"
 using namespace rheolef;
 using namespace std;
-int main(int argc, char**argv)
-{
-    environment parallel(argc, argv);
-
-    size_t nrow;
-    size_t ncol;
-    pcin >> nrow >> ncol;
-    asr<Float> a(nrow, ncol);
-    pcin >> a;
-
-    csr<Float> b(a);
-    asr<Float> a1(b);
-    
-    pcout << a1.par_nrow() << " " 
-	  << a1.par_ncol() << " " 
-	  << a1.par_nnz()  << endl
-          << a1
-	  ;
+int main(int argc, char**argv) {
+  environment distributed(argc, argv);
+  csr<Float> a;
+  dcin  >> a; 
+  dcout << a;
 }
