@@ -18,10 +18,10 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-#include "rheolef/parstream.h"
+#include "rheolef/diststream.h"
 using namespace std;
 using namespace rheolef;
 int main(int argc, char**argv) {
-    environment parallel(argc, argv);
-    pcout << "io_proc = " << oparstream::io_proc() << endl;
+    environment distributed(argc, argv);
+    dcout << "io_proc = " << odiststream::io_proc() << endl;
 }
