@@ -18,19 +18,19 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-# include "rheolef/parstream.h"
+# include "rheolef/diststream.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv)
 {
-    environment parallel(argc, argv);
+    environment distributed(argc, argv);
     cerr << "debut[A]"<<endl<<flush;
 #ifdef _RHEOLEF_HAVE_MPI
     cerr << "iproc=" <<mpi::communicator().rank()<< endl;
     cerr << "nproc=" <<mpi::communicator().size()<< endl;
 #endif // _RHEOLEF_HAVE_MPI
-    pcerr << "x ? " << endl;
+    dcerr << "x ? " << endl;
     Float x;
-    pcin >> x;
-    pcout << "x = " << x << endl;
+    dcin >> x;
+    dcout << "x = " << x << endl;
 }
