@@ -19,22 +19,19 @@
 ///
 /// =========================================================================
 # include "rheolef/array.h"
-# include "rheolef/parstream.h"
-# include "rheolef/par_inner_product.h"
+# include "rheolef/diststream.h"
+# include "rheolef/dis_accumulate.h"
+# include "rheolef/dis_inner_product.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv)
 {
-    environment parallel(argc, argv);
+    environment distributed(argc, argv);
     array<Float> x(100, Float(2.0)/Float(3.0));
-    Float norme2_x = par_inner_product (x.begin(),x.end(),x.begin(),x.comm()); 
-    int ndigit;
-    switch(sizeof(Float)) {
-      case 16: ndigit = 20;
-      case 8: 
-      default: ndigit = 10;
-    };
-    cout.precision(ndigit);
-    pcout << "dot(x,x) = " << norme2_x << endl;
+    Float sum_x    = dis_accumulate    (x.begin(),x.size(),x.comm()); 
+    Float norme2_x = dis_inner_product (x.begin(),x.begin(),x.size(),x.comm()); 
+    dcout << setprecision(10) 
+          << "dot(x,1) = " << sum_x    << endl
+          << "dot(x,x) = " << norme2_x << endl;
     return 0;
 }
