@@ -27,15 +27,15 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-    environment parallel(argc, argv); 
+    environment distributed(argc, argv); 
     size_t n = (argc < 2) ? 101 : atoi(argv[1]);
     array<Float> x(n, 0.0);
     if (x.comm().rank() == 0) {
-        for (size_t i = 0; i < x.par_size(); i++) {
-	    x.set (i,   1000+i+0.5);
+        for (size_t i = 0; i < x.dis_size(); i++) {
+	    x.dis_entry (i) = 1000+i+0.5;
         }
     }
-    x.assembly(); 
-    pcout << x.par_size() << endl
+    x.dis_entry_assembly(); 
+    dcout << x.dis_size() << endl
           << x            << endl;
 }
