@@ -23,11 +23,11 @@ using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv)
 {
-    environment parallel(argc, argv);
+    environment distributed(argc, argv);
     size_t n;
-    pcin >> n;
+    dcin >> n;
     array<Float> x(n);
-    pcin >> x;
-    pcout << x.par_size() << endl 
+    dcin >> x;
+    dcout << x.dis_size() << endl 
           << x            << endl;
 }
