@@ -18,30 +18,21 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-# include "rheolef/parallel.h"
+# include "rheolef/distributed.h"
 # include "rheolef/array.h"
 using namespace rheolef;
 using namespace std;
-int main(int argc, char**argv)
-{
-    environment parallel(argc, argv);
-  
+int main(int argc, char**argv) {
+    environment distributed(argc, argv);
     size_t n = 101;
-warning_macro ("CSTOR...");
     array<Float> x(n,0.0);
-warning_macro ("CSTOR done");
-
-    size_t first = x.first_index();
-    size_t last  = x.last_index();
-warning_macro ("ADDING...");
+    size_t first = x.ownership().first_index();
+    size_t last  = x.ownership().last_index();
     for (size_t i_global = 0; i_global < n; i_global++) {
     	if (i_global >= first && i_global < last) {
-	    x.set (i_global,   1000+i_global+0.5);
+	    x.dis_entry (i_global) = 1000+i_global+0.5;
         }
     }
-warning_macro ("ADDING done");
-warning_macro ("PRINTING...");
-    pcout << x.par_size() << endl
+    dcout << x.dis_size() << endl
           << x            << endl;
-warning_macro ("PRINTING done");
 }
