@@ -152,7 +152,6 @@ orheostream::~orheostream ()
 void
 irheostream::open (const string& name, const string& suffix)
 {
-    warning_macro ("irheostream::open("<<name<<","<<suffix<<")...");
     using namespace io;
 
     // get full file path with the optional '.gz' suffix:
@@ -173,7 +172,6 @@ irheostream::open (const string& name, const string& suffix)
       filtering_stream<input>::push (gzip_decompressor());    
     }
     filtering_stream<input>::push (_ifs);    
-    warning_macro ("irheostream::open("<<name<<","<<suffix<<") done");
 }
 void
 irheostream::close ()
