@@ -25,7 +25,7 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 
 status=0
 for file in in-animal-s2; do
-  run "RHEOPATH=.:${TOP_SRCDIR}/skit/tst ./irheostream_tst $file hb 2>/dev/null | /bin/sh $TOP_SRCDIR/config/zdiff - ${TOP_SRCDIR}/skit/tst/$file.hb.gz >/dev/null"
+  run "RHEOPATH=.:${TOP_SRCDIR}/skit/tst ./irheostream_tst $file hb 2>/dev/null | /bin/sh $TOP_SRCDIR/config/zdiff ${TOP_SRCDIR}/skit/tst/$file.hb.gz - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 exit $status
